* Dennis Kaarsemaker <dennis@kaarsemaker.net>
* Atamert Ölçgun <muhuk@muhuk.com>
* Alireza Savand <alireza.savand@gmail.com>
* Martin Burchell <martinb@aptivate.org>
* Daniel Lawrence <dannyla@linux.com>
* Fabio C. Barrionuevo da Luz <bnafta@gmail.com>

